/********************************************************************************
** Form generated from reading UI file 'configPage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGPAGE_H
#define UI_CONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_configPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLineEdit *kcfg_player3Name;
    QCheckBox *kcfg_player6IsHuman;
    QHBoxLayout *hboxLayout;
    QLabel *label_5;
    QSpinBox *kcfg_numberOfPlayers;
    QLabel *label_2_2;
    QCheckBox *kcfg_player3IsHuman;
    QLabel *label_2;
    QLineEdit *kcfg_player2Name;
    QCheckBox *kcfg_player2IsHuman;
    QLabel *label;
    QLineEdit *kcfg_player1Name;
    QCheckBox *kcfg_player1IsHuman;
    QLabel *label_2_2_2;
    QLineEdit *kcfg_player4Name;
    QCheckBox *kcfg_player4IsHuman;
    QLabel *label_2_3;
    QLineEdit *kcfg_player5Name;
    QCheckBox *kcfg_player5IsHuman;
    QLabel *label_2_3_2;
    QLineEdit *kcfg_player6Name;
    QHBoxLayout *hboxLayout1;
    QLabel *label_3;
    QSpinBox *kcfg_waitTime;
    QHBoxLayout *horizontalLayout;
    QLabel *fontSizeLabel;
    QSpinBox *kcfg_fontSize;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QSpinBox *kcfg_rowHeight;
    QCheckBox *kcfg_startupDemoEnabled;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *configPage)
    {
        if (configPage->objectName().isEmpty())
            configPage->setObjectName("configPage");
        configPage->resize(401, 378);
        verticalLayout = new QVBoxLayout(configPage);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(configPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_player3Name = new QLineEdit(groupBox);
        kcfg_player3Name->setObjectName("kcfg_player3Name");

        gridLayout->addWidget(kcfg_player3Name, 3, 1, 1, 1);

        kcfg_player6IsHuman = new QCheckBox(groupBox);
        kcfg_player6IsHuman->setObjectName("kcfg_player6IsHuman");

        gridLayout->addWidget(kcfg_player6IsHuman, 6, 2, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        hboxLayout->addWidget(label_5);

        kcfg_numberOfPlayers = new QSpinBox(groupBox);
        kcfg_numberOfPlayers->setObjectName("kcfg_numberOfPlayers");

        hboxLayout->addWidget(kcfg_numberOfPlayers);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 3);

        label_2_2 = new QLabel(groupBox);
        label_2_2->setObjectName("label_2_2");
        label_2_2->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(label_2_2, 3, 0, 1, 1);

        kcfg_player3IsHuman = new QCheckBox(groupBox);
        kcfg_player3IsHuman->setObjectName("kcfg_player3IsHuman");

        gridLayout->addWidget(kcfg_player3IsHuman, 3, 2, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        kcfg_player2Name = new QLineEdit(groupBox);
        kcfg_player2Name->setObjectName("kcfg_player2Name");

        gridLayout->addWidget(kcfg_player2Name, 2, 1, 1, 1);

        kcfg_player2IsHuman = new QCheckBox(groupBox);
        kcfg_player2IsHuman->setObjectName("kcfg_player2IsHuman");

        gridLayout->addWidget(kcfg_player2IsHuman, 2, 2, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setEnabled(true);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        kcfg_player1Name = new QLineEdit(groupBox);
        kcfg_player1Name->setObjectName("kcfg_player1Name");

        gridLayout->addWidget(kcfg_player1Name, 1, 1, 1, 1);

        kcfg_player1IsHuman = new QCheckBox(groupBox);
        kcfg_player1IsHuman->setObjectName("kcfg_player1IsHuman");
        kcfg_player1IsHuman->setEnabled(false);
        kcfg_player1IsHuman->setCheckable(true);
        kcfg_player1IsHuman->setChecked(true);

        gridLayout->addWidget(kcfg_player1IsHuman, 1, 2, 1, 1);

        label_2_2_2 = new QLabel(groupBox);
        label_2_2_2->setObjectName("label_2_2_2");

        gridLayout->addWidget(label_2_2_2, 4, 0, 1, 1);

        kcfg_player4Name = new QLineEdit(groupBox);
        kcfg_player4Name->setObjectName("kcfg_player4Name");

        gridLayout->addWidget(kcfg_player4Name, 4, 1, 1, 1);

        kcfg_player4IsHuman = new QCheckBox(groupBox);
        kcfg_player4IsHuman->setObjectName("kcfg_player4IsHuman");

        gridLayout->addWidget(kcfg_player4IsHuman, 4, 2, 1, 1);

        label_2_3 = new QLabel(groupBox);
        label_2_3->setObjectName("label_2_3");

        gridLayout->addWidget(label_2_3, 5, 0, 1, 1);

        kcfg_player5Name = new QLineEdit(groupBox);
        kcfg_player5Name->setObjectName("kcfg_player5Name");

        gridLayout->addWidget(kcfg_player5Name, 5, 1, 1, 1);

        kcfg_player5IsHuman = new QCheckBox(groupBox);
        kcfg_player5IsHuman->setObjectName("kcfg_player5IsHuman");

        gridLayout->addWidget(kcfg_player5IsHuman, 5, 2, 1, 1);

        label_2_3_2 = new QLabel(groupBox);
        label_2_3_2->setObjectName("label_2_3_2");

        gridLayout->addWidget(label_2_3_2, 6, 0, 1, 1);

        kcfg_player6Name = new QLineEdit(groupBox);
        kcfg_player6Name->setObjectName("kcfg_player6Name");

        gridLayout->addWidget(kcfg_player6Name, 6, 1, 1, 1);


        verticalLayout->addWidget(groupBox);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        label_3 = new QLabel(configPage);
        label_3->setObjectName("label_3");

        hboxLayout1->addWidget(label_3);

        kcfg_waitTime = new QSpinBox(configPage);
        kcfg_waitTime->setObjectName("kcfg_waitTime");

        hboxLayout1->addWidget(kcfg_waitTime);


        verticalLayout->addLayout(hboxLayout1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        fontSizeLabel = new QLabel(configPage);
        fontSizeLabel->setObjectName("fontSizeLabel");

        horizontalLayout->addWidget(fontSizeLabel);

        kcfg_fontSize = new QSpinBox(configPage);
        kcfg_fontSize->setObjectName("kcfg_fontSize");
        kcfg_fontSize->setMinimumSize(QSize(324, 0));

        horizontalLayout->addWidget(kcfg_fontSize);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_4 = new QLabel(configPage);
        label_4->setObjectName("label_4");

        horizontalLayout_2->addWidget(label_4);

        kcfg_rowHeight = new QSpinBox(configPage);
        kcfg_rowHeight->setObjectName("kcfg_rowHeight");
        kcfg_rowHeight->setMinimumSize(QSize(324, 0));

        horizontalLayout_2->addWidget(kcfg_rowHeight);


        verticalLayout->addLayout(horizontalLayout_2);

        kcfg_startupDemoEnabled = new QCheckBox(configPage);
        kcfg_startupDemoEnabled->setObjectName("kcfg_startupDemoEnabled");
        kcfg_startupDemoEnabled->setChecked(true);

        verticalLayout->addWidget(kcfg_startupDemoEnabled);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);

        QWidget::setTabOrder(kcfg_numberOfPlayers, kcfg_player1Name);
        QWidget::setTabOrder(kcfg_player1Name, kcfg_player1IsHuman);
        QWidget::setTabOrder(kcfg_player1IsHuman, kcfg_player2Name);
        QWidget::setTabOrder(kcfg_player2Name, kcfg_player2IsHuman);
        QWidget::setTabOrder(kcfg_player2IsHuman, kcfg_player3Name);
        QWidget::setTabOrder(kcfg_player3Name, kcfg_player3IsHuman);
        QWidget::setTabOrder(kcfg_player3IsHuman, kcfg_player4Name);
        QWidget::setTabOrder(kcfg_player4Name, kcfg_player4IsHuman);
        QWidget::setTabOrder(kcfg_player4IsHuman, kcfg_player5Name);
        QWidget::setTabOrder(kcfg_player5Name, kcfg_player5IsHuman);
        QWidget::setTabOrder(kcfg_player5IsHuman, kcfg_player6Name);
        QWidget::setTabOrder(kcfg_player6Name, kcfg_player6IsHuman);
        QWidget::setTabOrder(kcfg_player6IsHuman, kcfg_waitTime);

        retranslateUi(configPage);

        QMetaObject::connectSlotsByName(configPage);
    } // setupUi

    void retranslateUi(QWidget *configPage)
    {
        groupBox->setTitle(tr2i18n("Players", nullptr));
        kcfg_player3Name->setText(QString());
        kcfg_player6IsHuman->setText(tr2i18n("human?", nullptr));
        label_5->setText(tr2i18n("Number of players:", nullptr));
        label_2_2->setText(tr2i18n("3.", nullptr));
        kcfg_player3IsHuman->setText(tr2i18n("human?", nullptr));
        label_2->setText(tr2i18n("2.", nullptr));
        kcfg_player2Name->setText(QString());
        kcfg_player2IsHuman->setText(tr2i18n("human?", nullptr));
        label->setText(tr2i18n("1.", nullptr));
        kcfg_player1Name->setText(QString());
        kcfg_player1IsHuman->setText(tr2i18n("human?", nullptr));
        label_2_2_2->setText(tr2i18n("4.", nullptr));
        kcfg_player4Name->setText(QString());
        kcfg_player4IsHuman->setText(tr2i18n("human?", nullptr));
        label_2_3->setText(tr2i18n("5.", nullptr));
        kcfg_player5Name->setText(QString());
        kcfg_player5IsHuman->setText(tr2i18n("human?", nullptr));
        label_2_3_2->setText(tr2i18n("6.", nullptr));
        kcfg_player6Name->setText(QString());
        label_3->setText(tr2i18n("Delay between computers move (msec):", nullptr));
        fontSizeLabel->setText(tr2i18n("Font Size:", nullptr));
        label_4->setText(tr2i18n("Row Height:", nullptr));
        kcfg_startupDemoEnabled->setText(tr2i18n("Show demonstration game at startup", nullptr));
        (void)configPage;
    } // retranslateUi

};

namespace Ui {
    class configPage: public Ui_configPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGPAGE_H

