// This file is generated by kconfig_compiler_kf6 from kiriki.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <qglobal.h>
#include <QFile>

class kirikiSettingsHelper
{
  public:
    kirikiSettingsHelper() : q(nullptr) {}
    ~kirikiSettingsHelper() { delete q; q = nullptr; }
    kirikiSettingsHelper(const kirikiSettingsHelper&) = delete;
    kirikiSettingsHelper& operator=(const kirikiSettingsHelper&) = delete;
    kirikiSettings *q;
};
Q_GLOBAL_STATIC(kirikiSettingsHelper, s_globalkirikiSettings)
kirikiSettings *kirikiSettings::self()
{
  if (!s_globalkirikiSettings()->q) {
    new kirikiSettings;
    s_globalkirikiSettings()->q->read();
  }

  return s_globalkirikiSettings()->q;
}

kirikiSettings::kirikiSettings( )
  : KConfigSkeleton( QStringLiteral( "kirikirc" ) )
{
  Q_ASSERT(!s_globalkirikiSettings()->q);
  s_globalkirikiSettings()->q = this;
  setCurrentGroup( QStringLiteral( "general" ) );

  KConfigSkeleton::ItemInt  *itemWaitTime;
  itemWaitTime = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "waitTime" ), mWaitTime, 150 );
  itemWaitTime->setMinValue(0);
  itemWaitTime->setMaxValue(2000);
  addItem( itemWaitTime, QStringLiteral( "waitTime" ) );
  KConfigSkeleton::ItemInt  *itemNumberOfPlayers;
  itemNumberOfPlayers = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "numberOfPlayers" ), mNumberOfPlayers, 6 );
  itemNumberOfPlayers->setMinValue(2);
  itemNumberOfPlayers->setMaxValue(6);
  addItem( itemNumberOfPlayers, QStringLiteral( "numberOfPlayers" ) );
  KConfigSkeleton::ItemBool  *itemStartupDemoEnabled;
  itemStartupDemoEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "startupDemoEnabled" ), mStartupDemoEnabled, true );
  addItem( itemStartupDemoEnabled, QStringLiteral( "startupDemoEnabled" ) );

			  QFont f;
			  int defaultSize = f.pointSize();
			
  KConfigSkeleton::ItemInt  *itemFontSize;
  itemFontSize = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "fontSize" ), mFontSize, defaultSize );
  itemFontSize->setMinValue(5);
  itemFontSize->setMaxValue(20);
  addItem( itemFontSize, QStringLiteral( "fontSize" ) );
  KConfigSkeleton::ItemInt  *itemRowHeight;
  itemRowHeight = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "rowHeight" ), mRowHeight, defaultSize );
  itemRowHeight->setMaxValue(20);
  addItem( itemRowHeight, QStringLiteral( "rowHeight" ) );

			QString playerName1 = i18nc("default name of first player", "Albert");
		
  KConfigSkeleton::ItemString  *itemPlayer1Name;
  itemPlayer1Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player1Name" ), mPlayer1Name, playerName1 );
  addItem( itemPlayer1Name, QStringLiteral( "player1Name" ) );

			QString playerName2 = i18nc("default name of second player", "Janet");
		
  KConfigSkeleton::ItemString  *itemPlayer2Name;
  itemPlayer2Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player2Name" ), mPlayer2Name, playerName2 );
  addItem( itemPlayer2Name, QStringLiteral( "player2Name" ) );

			QString playerName3 = i18nc("default name of third player", "James");
		
  KConfigSkeleton::ItemString  *itemPlayer3Name;
  itemPlayer3Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player3Name" ), mPlayer3Name, playerName3 );
  addItem( itemPlayer3Name, QStringLiteral( "player3Name" ) );

			QString playerName4 = i18nc("default name of fourth player", "Sandra");
		
  KConfigSkeleton::ItemString  *itemPlayer4Name;
  itemPlayer4Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player4Name" ), mPlayer4Name, playerName4 );
  addItem( itemPlayer4Name, QStringLiteral( "player4Name" ) );

			QString playerName5 = i18nc("default name of fifth player", "Thomas");
		
  KConfigSkeleton::ItemString  *itemPlayer5Name;
  itemPlayer5Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player5Name" ), mPlayer5Name, playerName5 );
  addItem( itemPlayer5Name, QStringLiteral( "player5Name" ) );

			QString playerName6 = i18nc("default name of sixth player", "Margaret");
		
  KConfigSkeleton::ItemString  *itemPlayer6Name;
  itemPlayer6Name = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "player6Name" ), mPlayer6Name, playerName6 );
  addItem( itemPlayer6Name, QStringLiteral( "player6Name" ) );
  KConfigSkeleton::ItemBool  *itemPlayer1IsHuman;
  itemPlayer1IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player1IsHuman" ), mPlayer1IsHuman, true );
  addItem( itemPlayer1IsHuman, QStringLiteral( "player1IsHuman" ) );
  KConfigSkeleton::ItemBool  *itemPlayer2IsHuman;
  itemPlayer2IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player2IsHuman" ), mPlayer2IsHuman, false );
  addItem( itemPlayer2IsHuman, QStringLiteral( "player2IsHuman" ) );
  KConfigSkeleton::ItemBool  *itemPlayer3IsHuman;
  itemPlayer3IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player3IsHuman" ), mPlayer3IsHuman, false );
  addItem( itemPlayer3IsHuman, QStringLiteral( "player3IsHuman" ) );
  KConfigSkeleton::ItemBool  *itemPlayer4IsHuman;
  itemPlayer4IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player4IsHuman" ), mPlayer4IsHuman, false );
  addItem( itemPlayer4IsHuman, QStringLiteral( "player4IsHuman" ) );
  KConfigSkeleton::ItemBool  *itemPlayer5IsHuman;
  itemPlayer5IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player5IsHuman" ), mPlayer5IsHuman, false );
  addItem( itemPlayer5IsHuman, QStringLiteral( "player5IsHuman" ) );
  KConfigSkeleton::ItemBool  *itemPlayer6IsHuman;
  itemPlayer6IsHuman = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "player6IsHuman" ), mPlayer6IsHuman, false );
  addItem( itemPlayer6IsHuman, QStringLiteral( "player6IsHuman" ) );
}

kirikiSettings::~kirikiSettings()
{
  if (s_globalkirikiSettings.exists() && !s_globalkirikiSettings.isDestroyed()) {
    s_globalkirikiSettings()->q = nullptr;
  }
}

